from setuptools import setup

setup(
    name="shopagent",
    version="0.7.0",
    packages=['shopagent', 'shopagent.api', 'shopagent.code_gen', 'shopagent.constants', 'shopagent.lsd', 'shopagent.nav']
)
